AssertionUpdate

Enum AssertionUpdate 

pub enum AssertionUpdate<T> {
    Asserted(Identifier, T),
    Retracted(Identifier),
}
An update received by a subscription, indicating that a value was asserted or retracted.

Variants



Asserted(Identifier, T)

A value was asserted (made available), along with the identifier it is associated with.



Retracted(Identifier)

The value associated with the given identifier was retracted (withdrawn).