Subscription

Struct Subscription 

pub struct Subscription<T> { /* private fields */ }
A subscription to updates for a specific type/identifier combination.

Implementations

Source

impl<T> Subscription<T>
where T: Clone + Send + Sync + 'static,

pub async fn recv(&mut self) -> Option<AssertionUpdate<T>>

Receives the next assertion or retraction update.

Returns Some(update) when an update is available, or None if the channel has been closed (all senders dropped). If messages were missed due to the subscriber falling behind, the missed messages are skipped and the next available update is returned.