DataspaceRegistry

Struct DataspaceRegistry 

pub struct DataspaceRegistry { /* private fields */ }
A dataspace registry for async coordination between processes.

The registry stores broadcast channels indexed by type and Identifier. Processes can subscribe to receive assertion and retraction updates for a given type and identifier filter, and other processes can assert or retract values that are delivered to all matching subscribers.

Thread Safety

DataspaceRegistry is Clone and can be safely shared across threadVs and tasks. All operations are thread-safe.

Implementations

Source

impl DataspaceRegistry

pub fn new() -> Self

Creates a new empty registry with the default channel capacity.

pub fn try_current() -> Option<Self>

Returns the dataspace registry for the current supervision tree, if one exists.

pub fn with_channel_capacity(capacity: usize) -> Self

Creates a new empty registry with the given channel capacity for broadcast channels.

pub fn assert<T>(&self, value: T, id: impl Into<Identifier>)
where T: Clone + Send + Sync + 'static,

Asserts a value with the given identifier, notifying all matching subscribers.

The assertion is automatically associated with the current process, and will be automatically retracted when that process exists. Only the owning process may update an existing assertion for a given type/identifier combination.

pub fn retract<T>(&self, id: impl Into<Identifier>)
where T: Clone + Send + Sync + 'static,

Retracts the value of the given type and identifier, notifying all matching subscribers.

Only the process that originally asserted the value may retract it.

pub fn subscribe<T>(&self, filter: IdentifierFilter) -> Subscription<T>
where T: Clone + Send + Sync + 'static,

Subscribes to assertion and retraction updates matching the given filter.

Returns a Subscription that can be used to asynchronously receive updates. Any assertions that match the filter at the time of subscribing will be immediately yielded.