pub struct DataspaceRegistry { /* private fields */ }Expand description
A dataspace registry for async coordination between processes.
The registry stores broadcast channels indexed by type and Identifier. Processes can subscribe to receive
assertion and retraction updates for a given type and identifier filter, and other processes can assert or retract
values that are delivered to all matching subscribers.
Thread Safety
DataspaceRegistry is Clone and can be safely shared across threadVs and tasks. All operations are thread-safe.
Implementations
Sourceimpl DataspaceRegistry
impl DataspaceRegistry
Sourcepub fn try_current() -> Option<Self>
pub fn try_current() -> Option<Self>
Returns the dataspace registry for the current supervision tree, if one exists.
Sourcepub fn with_channel_capacity(capacity: usize) -> Self
pub fn with_channel_capacity(capacity: usize) -> Self
Creates a new empty registry with the given channel capacity for broadcast channels.
Sourcepub fn assert<T>(&self, value: T, id: impl Into<Identifier>)
pub fn assert<T>(&self, value: T, id: impl Into<Identifier>)
Asserts a value with the given identifier, notifying all matching subscribers.
The assertion is automatically associated with the current process, and will be automatically retracted when that process exists. Only the owning process may update an existing assertion for a given type/identifier combination.
Sourcepub fn retract<T>(&self, id: impl Into<Identifier>)
pub fn retract<T>(&self, id: impl Into<Identifier>)
Retracts the value of the given type and identifier, notifying all matching subscribers.
Only the process that originally asserted the value may retract it.
Sourcepub fn subscribe<T>(&self, filter: IdentifierFilter) -> Subscription<T>
pub fn subscribe<T>(&self, filter: IdentifierFilter) -> Subscription<T>
Subscribes to assertion and retraction updates matching the given filter.
Returns a Subscription that can be used to asynchronously receive updates. Any assertions that match the
filter at the time of subscribing will be immediately yielded.